Crate hill_vacuum_proc_macros
Source - bind_enum
- Generates the
Bind enum plus the config_file_key() and label() methods. - color_enum
- Generates a function which associates a f32 value representing a certain height to each provided
enum match arm.
- embedded_assets
- Generates the function calls to store the embedded assets from the file names in the
src/embedded_assets/ folder. - generate_manual
- Generates the built-in manual from some of the markdown files in the
docs directory. - meshes_indexes
- Generates the vector of the indexes used to triangulate the meshes.
- sin_cos_tan_array
- Generates the sin, cos, tan, lookup table.
- str_array
- Generates an array of static
str with name, size, and prefix defined in stream.
- EnumFromUsize
- Implements From
usize for a plain enum. - EnumIter
- Implements a method that returns an iterator to the values of a plain enum.
- EnumSize
- Implements a constant representing the size of the
input enum. - SubToolEnum
- Implements the vast majority of the methods of the
SubTool enum. - ToolEnum
- Implements the vast majority of the methods of the
Tool enum.